@@ -21,10 +21,23 @@ class ConstExprArrayNode implements ConstExprNode
 		$this->items = $items;
 	}
 
-
 	public function __toString(): string
 	{
 		return '[' . implode(', ', $this->items) . ']';
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['items']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
