@@ -10,10 +10,9 @@ class ConstFetchNode implements ConstExprNode
 	use NodeAttributes;
 
 	/** @var string class name for class constants or empty string for non-class constants */
-	public $className;
+	public string $className;
 
-	/** @var string */
-	public $name;
+	public string $name;
 
 	public function __construct(string $className, string $name)
 	{
@@ -21,7 +20,6 @@ class ConstFetchNode implements ConstExprNode
 		$this->name = $name;
 	}
 
-
 	public function __toString(): string
 	{
 		if ($this->className === '') {
@@ -32,4 +30,18 @@ class ConstFetchNode implements ConstExprNode
 		return "{$this->className}::{$this->name}";
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['className'], $properties['name']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
