@@ -13,12 +13,11 @@ class DoctrineConstExprStringNode extends ConstExprStringNode
 
 	use NodeAttributes;
 
-	/** @var string */
-	public $value;
+	public string $value;
 
 	public function __construct(string $value)
 	{
-		parent::__construct($value);
+		parent::__construct($value, self::DOUBLE_QUOTED);
 		$this->value = $value;
 	}
 
@@ -39,4 +38,18 @@ class DoctrineConstExprStringNode extends ConstExprStringNode
 		return sprintf('"%s"', str_replace('"', '""', $value));
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['value']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
