@@ -26,4 +26,18 @@ class ParamLaterInvokedCallableTagValueNode implements PhpDocTagValueNode
 		return trim("{$this->parameterName} {$this->description}");
 	}
 
+	/**
+	 * @param array<string, mixed> $properties
+	 */
+	public static function __set_state(array $properties): self
+	{
+		$instance = new self($properties['parameterName'], $properties['description']);
+		if (isset($properties['attributes'])) {
+			foreach ($properties['attributes'] as $key => $value) {
+				$instance->setAttribute($key, $value);
+			}
+		}
+		return $instance;
+	}
+
 }
